@@ -50,7 +50,7 @@ import elasticapm
 from elasticapm.conf import Config, VersionedConfig, constants
 from elasticapm.conf.constants import ERROR
 from elasticapm.metrics.base_metrics import MetricsRegistry
-from elasticapm.traces import Tracer, execution_context
+from elasticapm.traces import DroppedSpan, Tracer, execution_context
 from elasticapm.utils import cgroup, cloud, compat, is_master_process, stacks, varmap
 from elasticapm.utils.disttracing import TraceParent
 from elasticapm.utils.encoding import enforce_label_format, keyword_field, shorten, transform
@@ -140,8 +140,6 @@ class Client(object):
                 logging.setLogRecordFactory(new_factory)
 
         headers = {
-            "Content-Type": "application/x-ndjson",
-            "Content-Encoding": "gzip",
             "User-Agent": self.get_user_agent(),
         }
 
@@ -200,15 +198,15 @@ class Client(object):
         )
         self.include_paths_re = stacks.get_path_regex(self.config.include_paths) if self.config.include_paths else None
         self.exclude_paths_re = stacks.get_path_regex(self.config.exclude_paths) if self.config.exclude_paths else None
-        self._metrics = MetricsRegistry(self)
+        self.metrics = MetricsRegistry(self)
         for path in self.config.metrics_sets:
-            self._metrics.register(path)
+            self.metrics.register(path)
         if self.config.breakdown_metrics:
-            self._metrics.register("elasticapm.metrics.sets.breakdown.BreakdownMetricSet")
+            self.metrics.register("elasticapm.metrics.sets.breakdown.BreakdownMetricSet")
         if self.config.prometheus_metrics:
-            self._metrics.register("elasticapm.metrics.sets.prometheus.PrometheusMetrics")
+            self.metrics.register("elasticapm.metrics.sets.prometheus.PrometheusMetrics")
         if self.config.metrics_interval:
-            self._thread_managers["metrics"] = self._metrics
+            self._thread_managers["metrics"] = self.metrics
         compat.atexit_register(self.close)
         if self.config.central_config:
             self._thread_managers["config"] = self.config
@@ -220,6 +218,8 @@ class Client(object):
         if config.enabled:
             self.start_threads()
 
+        self.activation_method = None
+
         # Save this Client object as the global CLIENT_SINGLETON
         set_client(self)
 
@@ -304,6 +304,7 @@ class Client(object):
         :param trace_parent: an optional TraceParent object for distributed tracing
         :param start: override the start timestamp, mostly useful for testing
         :param auto_activate: whether to set this transaction in execution_context
+        :param links: a sequence of traceparent objects to causally link this transaction with
         :return: the started transaction object
         """
         if self.config.is_recording:
@@ -470,6 +471,8 @@ class Client(object):
         """
         transaction = execution_context.get_transaction()
         span = execution_context.get_span()
+        while isinstance(span, DroppedSpan):
+            span = span.parent
         if transaction:
             transaction_context = deepcopy(transaction.context)
         else:
@@ -657,16 +660,8 @@ class Client(object):
 
     def check_python_version(self):
         v = tuple(map(int, platform.python_version_tuple()[:2]))
-        if v == (2, 7):
-            warnings.warn(
-                (
-                    "The Elastic APM agent will stop supporting Python 2.7 starting in 6.0.0 -- "
-                    "Please upgrade to Python 3.5+ to continue to use the latest features."
-                ),
-                PendingDeprecationWarning,
-            )
-        elif v < (3, 5):
-            warnings.warn("The Elastic APM agent only supports Python 3.5+", DeprecationWarning)
+        if v < (3, 6):
+            warnings.warn("The Elastic APM agent only supports Python 3.6+", DeprecationWarning)
 
     def check_server_version(
         self, gte: Optional[Tuple[int, ...]] = None, lte: Optional[Tuple[int, ...]] = None
@@ -684,6 +679,11 @@ class Client(object):
         lte = lte or (2**32,)  # let's assume APM Server version will never be greater than 2^32
         return bool(gte <= self.server_version <= lte)
 
+    @property
+    def _metrics(self):
+        warnings.warn(DeprecationWarning("Use `client.metrics` instead"))
+        return self.metrics
+
 
 class DummyClient(Client):
     """Sends messages into an empty void"""
