@@ -38,7 +38,7 @@ import socket
 import threading
 from datetime import timedelta
 
-from elasticapm.conf.constants import BASE_SANITIZE_FIELD_NAMES
+from elasticapm.conf.constants import BASE_SANITIZE_FIELD_NAMES, TRACE_CONTINUATION_STRATEGY
 from elasticapm.utils import compat, starmatch_to_regex
 from elasticapm.utils.logging import get_logger
 from elasticapm.utils.threading import IntervalTimer, ThreadManager
@@ -642,6 +642,7 @@ class Config(_ConfigBase):
     autoinsert_django_middleware = _BoolConfigValue("AUTOINSERT_DJANGO_MIDDLEWARE", default=True)
     transactions_ignore_patterns = _ListConfigValue("TRANSACTIONS_IGNORE_PATTERNS", default=[])
     transaction_ignore_urls = _ListConfigValue("TRANSACTION_IGNORE_URLS", type=starmatch_to_regex, default=[])
+    ignore_message_queues = _ListConfigValue("IGNORE_MESSAGE_QUEUES", type=starmatch_to_regex, default=[])
     service_version = _ConfigValue("SERVICE_VERSION")
     framework_name = _ConfigValue("FRAMEWORK_NAME")
     framework_version = _ConfigValue("FRAMEWORK_VERSION")
@@ -670,6 +671,19 @@ class Config(_ConfigBase):
         callbacks=[_log_ecs_reformatting_callback],
         default="off",
     )
+    trace_continuation_strategy = _ConfigValue(
+        "TRACE_CONTINUATION_STRATEGY",
+        validators=[
+            EnumerationValidator(
+                [
+                    TRACE_CONTINUATION_STRATEGY.CONTINUE,
+                    TRACE_CONTINUATION_STRATEGY.RESTART,
+                    TRACE_CONTINUATION_STRATEGY.RESTART_EXTERNAL,
+                ]
+            )
+        ],
+        default=TRACE_CONTINUATION_STRATEGY.CONTINUE,
+    )
 
     @property
     def is_recording(self):
