@@ -31,16 +31,17 @@
 import decimal
 import re
 from collections import namedtuple
+from typing import Pattern
 
 
-def _starmatch_to_regex(pattern):
+def _starmatch_to_regex(pattern: str) -> Pattern:
     """
     This is a duplicate of starmatch_to_regex() in utils/__init__.py
 
     Duplication to avoid circular imports
     """
     options = re.DOTALL
-    # check if we are case sensitive
+    # check if we are case-sensitive
     if pattern.startswith("(?-i)"):
         pattern = pattern[5:]
     else:
@@ -70,6 +71,7 @@ TRACESTATE_HEADER_NAME = "tracestate"
 TIMESTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 KEYWORD_MAX_LENGTH = 1024
+LONG_FIELD_MAX_LENGTH = 10000
 
 HTTP_WITH_BODY = {"POST", "PUT", "PATCH", "DELETE"}
 
@@ -97,6 +99,7 @@ BASE_SANITIZE_FIELD_NAMES_UNPROCESSED = [
     "*credit*",
     "*card*",
     "*auth*",
+    "*principal*",
     "set-cookie",
 ]
 
@@ -106,12 +109,7 @@ OUTCOME = namedtuple("OUTCOME", ["SUCCESS", "FAILURE", "UNKNOWN"])(
     SUCCESS="success", FAILURE="failure", UNKNOWN="unknown"
 )
 
-try:
-    # Python 2
-    LABEL_TYPES = (bool, int, long, float, decimal.Decimal)
-except NameError:
-    # Python 3
-    LABEL_TYPES = (bool, int, float, decimal.Decimal)
+LABEL_TYPES = (bool, int, float, decimal.Decimal)
 
 TRACESTATE = namedtuple("TRACESTATE", ["SAMPLE_RATE"])(SAMPLE_RATE="s")
 TRACE_CONTINUATION_STRATEGY = namedtuple("TRACE_CONTINUATION_STRATEGY", ["CONTINUE", "RESTART", "RESTART_EXTERNAL"])(
