@@ -46,6 +46,7 @@ from elasticapm.base import Client
 from elasticapm.conf import constants
 from elasticapm.contrib.django.utils import get_raw_uri, iterate_with_template_sources
 from elasticapm.utils import compat, encoding, get_url_dict
+from elasticapm.utils.encoding import long_field
 from elasticapm.utils.logging import get_logger
 from elasticapm.utils.module_import import import_string
 from elasticapm.utils.wsgi import get_environ, get_headers
@@ -149,7 +150,9 @@ class DjangoClient(Client):
                         self.logger.debug("Can't capture request body: %s", str(e))
                         data = "<unavailable>"
                 if data is not None:
-                    result["body"] = data
+                    # Can we apply this as a processor instead?
+                    # https://github.com/elastic/apm-agent-python/issues/305
+                    result["body"] = long_field(data)
 
         url = get_raw_uri(request)
         try:
