@@ -35,90 +35,110 @@ import json
 import os
 import platform
 import time
-from typing import Optional
+import warnings
+from typing import Optional, TypeVar
+from urllib.parse import urlencode
 
 import elasticapm
-from elasticapm.base import Client
+from elasticapm.base import Client, get_client
 from elasticapm.conf import constants
 from elasticapm.utils import encoding, get_name_from_func, nested_key
 from elasticapm.utils.disttracing import TraceParent
 from elasticapm.utils.logging import get_logger
 
+SERVERLESS_HTTP_REQUEST = ("api", "elb")
+
 logger = get_logger("elasticapm.serverless")
 
 COLD_START = True
+INSTRUMENTED = False
+
+_AWSLambdaContextT = TypeVar("_AWSLambdaContextT")
 
 
-class capture_serverless(object):
+def capture_serverless(func: Optional[callable] = None, **kwargs) -> callable:
     """
-    Context manager and decorator designed for instrumenting serverless
-    functions.
-
-    Begins and ends a single transaction, waiting for the transport to flush
-    before returning from the wrapped function.
+    Decorator for instrumenting AWS Lambda functions.
 
     Example usage:
 
         from elasticapm import capture_serverless
 
-        @capture_serverless()
+        @capture_serverless
         def handler(event, context):
             return {"statusCode": r.status_code, "body": "Success!"}
     """
+    if not func:
+        # This allows for `@capture_serverless()` in addition to
+        # `@capture_serverless` decorator usage
+        return functools.partial(capture_serverless, **kwargs)
 
-    def __init__(self, name: Optional[str] = None, elasticapm_client: Optional[Client] = None, **kwargs) -> None:
-        self.name = name
-        self.event = {}
-        self.context = {}
+    if kwargs:
+        warnings.warn(
+            PendingDeprecationWarning(
+                "Passing keyword arguments to capture_serverless will be deprecated in the next major release."
+            )
+        )
+
+    name = kwargs.pop("name", None)
+
+    # Disable all background threads except for transport
+    kwargs["metrics_interval"] = "0ms"
+    kwargs["breakdown_metrics"] = False
+    if "metrics_sets" not in kwargs and "ELASTIC_APM_METRICS_SETS" not in os.environ:
+        # Allow users to override metrics sets
+        kwargs["metrics_sets"] = []
+    kwargs["central_config"] = False
+    kwargs["cloud_provider"] = "none"
+    kwargs["framework_name"] = "AWS Lambda"
+    if "service_name" not in kwargs and "ELASTIC_APM_SERVICE_NAME" not in os.environ:
+        kwargs["service_name"] = os.environ["AWS_LAMBDA_FUNCTION_NAME"]
+    if "service_version" not in kwargs and "ELASTIC_APM_SERVICE_VERSION" not in os.environ:
+        kwargs["service_version"] = os.environ.get("AWS_LAMBDA_FUNCTION_VERSION")
+
+    global INSTRUMENTED
+    client = get_client()
+    if not client:
+        client = Client(**kwargs)
+    if not client.config.debug and client.config.instrument and client.config.enabled and not INSTRUMENTED:
+        elasticapm.instrument()
+        INSTRUMENTED = True
+
+    @functools.wraps(func)
+    def decorated(*args, **kwds):
+        if len(args) == 2:
+            # Saving these for request context later
+            event, context = args
+        else:
+            event, context = {}, {}
+
+        if not client.config.debug and client.config.instrument and client.config.enabled:
+            with _lambda_transaction(func, name, client, event, context) as sls:
+                sls.response = func(*args, **kwds)
+                return sls.response
+        else:
+            return func(*args, **kwds)
+
+    return decorated
+
+
+class _lambda_transaction(object):
+    """
+    Context manager for creating transactions around AWS Lambda functions.
+
+    Begins and ends a single transaction, waiting for the transport to flush
+    before releasing the context.
+    """
+
+    def __init__(
+        self, func: callable, name: Optional[str], client: Client, event: dict, context: _AWSLambdaContextT
+    ) -> None:
+        self.func = func
+        self.name = name or get_name_from_func(func)
+        self.event = event
+        self.context = context
         self.response = None
-        self.instrumented = False
-        self.client = elasticapm_client  # elasticapm_client is intended for testing only
-
-        # Disable all background threads except for transport
-        kwargs["metrics_interval"] = "0ms"
-        kwargs["central_config"] = False
-        kwargs["cloud_provider"] = "none"
-        kwargs["framework_name"] = "AWS Lambda"
-        if "service_name" not in kwargs and "ELASTIC_APM_SERVICE_NAME" not in os.environ:
-            kwargs["service_name"] = os.environ["AWS_LAMBDA_FUNCTION_NAME"]
-        if "service_version" not in kwargs and "ELASTIC_APM_SERVICE_VERSION" not in os.environ:
-            kwargs["service_version"] = os.environ.get("AWS_LAMBDA_FUNCTION_VERSION")
-
-        self.client_kwargs = kwargs
-
-    def __call__(self, func):
-        self.name = self.name or get_name_from_func(func)
-
-        @functools.wraps(func)
-        def decorated(*args, **kwds):
-            if len(args) == 2:
-                # Saving these for request context later
-                self.event, self.context = args
-            else:
-                self.event, self.context = {}, {}
-            # We delay client creation until the function is called, so that
-            # multiple @capture_serverless instances in the same file don't create
-            # multiple clients
-            if not self.client:
-                # Don't use get_client() as we may have a config mismatch due to **kwargs
-                self.client = Client(**self.client_kwargs)
-            if (
-                not self.instrumented
-                and not self.client.config.debug
-                and self.client.config.instrument
-                and self.client.config.enabled
-            ):
-                elasticapm.instrument()
-                self.instrumented = True
-
-            if not self.client.config.debug and self.client.config.instrument and self.client.config.enabled:
-                with self:
-                    self.response = func(*args, **kwds)
-                    return self.response
-            else:
-                return func(*args, **kwds)
-
-        return decorated
+        self.client = client
 
     def __enter__(self):
         """
@@ -134,18 +154,25 @@ class capture_serverless(object):
         transaction_type = "request"
         transaction_name = os.environ.get("AWS_LAMBDA_FUNCTION_NAME", self.name)
 
-        self.httpmethod = nested_key(self.event, "requestContext", "httpMethod") or nested_key(
-            self.event, "requestContext", "http", "method"
+        self.httpmethod = (
+            nested_key(self.event, "requestContext", "httpMethod")
+            or nested_key(self.event, "requestContext", "http", "method")
+            or nested_key(self.event, "httpMethod")
         )
-        if self.httpmethod:  # API Gateway
-            self.source = "api"
-            if nested_key(self.event, "requestContext", "httpMethod"):
+
+        if self.httpmethod:  # http request
+            if nested_key(self.event, "requestContext", "elb"):
+                self.source = "elb"
+                resource = "unknown route"
+            elif nested_key(self.event, "requestContext", "httpMethod"):
+                self.source = "api"
                 # API v1
                 resource = "/{}{}".format(
                     nested_key(self.event, "requestContext", "stage"),
                     nested_key(self.event, "requestContext", "resourcePath"),
                 )
             else:
+                self.source = "api"
                 # API v2
                 route_key = nested_key(self.event, "requestContext", "routeKey")
                 route_key = f"/{route_key}" if route_key.startswith("$") else route_key.split(" ", 1)[-1]
@@ -168,9 +195,18 @@ class capture_serverless(object):
                 transaction_type = "messaging"
                 transaction_name = "RECEIVE {}".format(record["eventSourceARN"].split(":")[5])
 
-        self.transaction = self.client.begin_transaction(transaction_type, trace_parent=trace_parent)
+        if "Records" in self.event:
+            links = [
+                TraceParent.from_string(record["messageAttributes"]["traceparent"]["stringValue"])
+                for record in self.event["Records"][:1000]
+                if "messageAttributes" in record and "traceparent" in record["messageAttributes"]
+            ]
+        else:
+            links = []
+
+        self.client.begin_transaction(transaction_type, trace_parent=trace_parent, links=links)
         elasticapm.set_transaction_name(transaction_name, override=False)
-        if self.source == "api":
+        if self.source in SERVERLESS_HTTP_REQUEST:
             elasticapm.set_context(
                 lambda: get_data_from_request(
                     self.event,
@@ -180,6 +216,7 @@ class capture_serverless(object):
                 "request",
             )
         self.set_metadata_and_context(cold_start)
+        return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         """
@@ -194,12 +231,15 @@ class capture_serverless(object):
                 try:
                     result = "HTTP {}xx".format(int(self.response["statusCode"]) // 100)
                     elasticapm.set_transaction_result(result, override=False)
+                    if result == "HTTP 5xx":
+                        elasticapm.set_transaction_outcome(outcome="failure", override=False)
                 except ValueError:
                     logger.warning("Lambda function's statusCode was not formed as an int. Assuming 5xx result.")
                     elasticapm.set_transaction_result("HTTP 5xx", override=False)
+                    elasticapm.set_transaction_outcome(outcome="failure", override=False)
         if exc_val:
             self.client.capture_exception(exc_info=(exc_type, exc_val, exc_tb), handled=False)
-            if self.source == "api":
+            if self.source in SERVERLESS_HTTP_REQUEST:
                 elasticapm.set_transaction_result("HTTP 5xx", override=False)
                 elasticapm.set_transaction_outcome(http_status_code=500, override=False)
                 elasticapm.set_context({"status_code": 500}, "response")
@@ -208,6 +248,8 @@ class capture_serverless(object):
                 elasticapm.set_transaction_outcome(outcome="failure", override=False)
 
         self.client.end_transaction()
+        # Collect any custom+prometheus metrics if enabled
+        self.client.metrics.collect()
 
         try:
             logger.debug("flushing elasticapm")
@@ -244,8 +286,20 @@ class capture_serverless(object):
             service_context["origin"]["version"] = self.event.get("version", "1.0")
             cloud_context["origin"] = {}
             cloud_context["origin"]["service"] = {"name": "api gateway"}
+            if ".lambda-url." in self.event["requestContext"]["domainName"]:
+                cloud_context["origin"]["service"]["name"] = "lambda url"
             cloud_context["origin"]["account"] = {"id": self.event["requestContext"]["accountId"]}
             cloud_context["origin"]["provider"] = "aws"
+        elif self.source == "elb":
+            elb_target_group_arn = self.event["requestContext"]["elb"]["targetGroupArn"]
+            faas["trigger"]["type"] = "http"
+            service_context["origin"] = {"name": elb_target_group_arn.split(":")[5].split("/")[1]}
+            service_context["origin"]["id"] = elb_target_group_arn
+            cloud_context["origin"] = {}
+            cloud_context["origin"]["service"] = {"name": "elb"}
+            cloud_context["origin"]["account"] = {"id": elb_target_group_arn.split(":")[4]}
+            cloud_context["origin"]["region"] = elb_target_group_arn.split(":")[3]
+            cloud_context["origin"]["provider"] = "aws"
         elif self.source == "sqs":
             record = self.event["Records"][0]
             faas["trigger"]["type"] = "pubsub"
@@ -281,7 +335,7 @@ class capture_serverless(object):
             service_context["origin"]["service"] = {"name": "sns"}
             cloud_context["origin"] = {}
             cloud_context["origin"]["region"] = record["Sns"]["TopicArn"].split(":")[3]
-            cloud_context["origin"]["account_id"] = record["Sns"]["TopicArn"].split(":")[4]
+            cloud_context["origin"]["account"] = {"id": record["Sns"]["TopicArn"].split(":")[4]}
             cloud_context["origin"]["provider"] = "aws"
             message_context["queue"] = {"name": service_context["origin"]["name"]}
             if "Timestamp" in record["Sns"]:
@@ -354,7 +408,13 @@ def get_data_from_request(event: dict, capture_body: bool = False, capture_heade
     result = {}
     if capture_headers and "headers" in event:
         result["headers"] = event["headers"]
-    method = nested_key(event, "requestContext", "httpMethod") or nested_key(event, "requestContext", "http", "method")
+
+    method = (
+        nested_key(event, "requestContext", "httpMethod")
+        or nested_key(event, "requestContext", "http", "method")
+        or nested_key(event, "httpMethod")
+    )
+
     if not method:
         # Not API Gateway
         return result
@@ -405,16 +465,23 @@ def get_url_dict(event: dict) -> dict:
     headers = event.get("headers", {})
     protocol = headers.get("X-Forwarded-Proto", headers.get("x-forwarded-proto", "https"))
     host = headers.get("Host", headers.get("host", ""))
-    stage = "/" + (nested_key(event, "requestContext", "stage") or "")
-    path = event.get("path", event.get("rawPath", "").split(stage)[-1])
+    stage = nested_key(event, "requestContext", "stage") or ""
+    raw_path = event.get("rawPath", "")
+    if stage:
+        stage = "/" + stage
+        raw_path = raw_path.split(stage)[-1]
+
+    path = event.get("path", raw_path)
     port = headers.get("X-Forwarded-Port", headers.get("x-forwarded-port"))
     query = ""
     if "rawQueryString" in event:
         query = event["rawQueryString"]
     elif event.get("queryStringParameters"):
-        query = "?"
-        for k, v in event["queryStringParameters"].items():
-            query += "{}={}".format(k, v)
+        if stage:  # api requires parameters encoding to build correct url
+            query = "?" + urlencode(event["queryStringParameters"])
+        else:  # for elb we do not have the stage
+            query = "?" + "&".join(["{}={}".format(k, v) for k, v in event["queryStringParameters"].items()])
+
     url = protocol + "://" + host + stage + path + query
 
     url_dict = {
