@@ -35,9 +35,10 @@ https://www.python.org/dev/peps/pep-0249/
 
 import re
 
+import wrapt
+
 from elasticapm.instrumentation.packages.base import AbstractInstrumentedModule
 from elasticapm.traces import capture_span
-from elasticapm.utils import wrapt
 from elasticapm.utils.encoding import force_text, shorten
 
 
@@ -235,7 +236,10 @@ class CursorProxy(wrapt.ObjectProxy):
             span_type="db",
             span_subtype=self.provider_name,
             span_action=action,
-            extra={"db": {"type": "sql", "statement": sql_string}, "destination": self._self_destination_info},
+            extra={
+                "db": {"type": "sql", "statement": sql_string, "instance": getattr(self, "_self_database", None)},
+                "destination": self._self_destination_info,
+            },
             skip_frames=1,
             leaf=True,
         ) as span:
