@@ -86,8 +86,14 @@ class RedisConnectionInstrumentation(AbstractInstrumentedModule):
 
     def call(self, module, method, wrapped, instance, args, kwargs):
         span = execution_context.get_span()
-        if span and span.subtype == "redis":
+        db_context = None
+        if args and len(args) > 1:
+            func_name = args[0].decode("utf-8") if isinstance(args[0], bytes) else args[0]
+            db_context = {"type": "query", "statement": "{} {}".format(func_name, args[1])}
+        if span and span.subtype == self.name:
             span.context["destination"] = get_destination_info(instance)
+            if db_context:
+                span.context["db"] = db_context
         return wrapped(*args, **kwargs)
 
 
