@@ -67,6 +67,8 @@ _cls_register = {
     "elasticapm.instrumentation.packages.httplib2.Httplib2Instrumentation",
     "elasticapm.instrumentation.packages.azure.AzureInstrumentation",
     "elasticapm.instrumentation.packages.kafka.KafkaInstrumentation",
+    "elasticapm.instrumentation.packages.grpc.GRPCClientInstrumentation",
+    "elasticapm.instrumentation.packages.grpc.GRPCServerInstrumentation",
 }
 
 if sys.version_info >= (3, 7):
@@ -88,14 +90,25 @@ if sys.version_info >= (3, 7):
             "elasticapm.instrumentation.packages.asyncio.aioredis.RedisConnectionInstrumentation",
             "elasticapm.instrumentation.packages.asyncio.aiomysql.AioMySQLInstrumentation",
             "elasticapm.instrumentation.packages.asyncio.aiobotocore.AioBotocoreInstrumentation",
+            "elasticapm.instrumentation.packages.asyncio.starlette.StarletteServerErrorMiddlewareInstrumentation",
         ]
     )
 
+# These instrumentations should only be enabled if we're instrumenting via the
+# wrapper script, which calls register_wrapper_instrumentations() below.
+_wrapper_register = {
+    "elasticapm.instrumentation.packages.flask.FlaskInstrumentation",
+}
+
 
 def register(cls):
     _cls_register.add(cls)
 
 
+def register_wrapper_instrumentations():
+    _cls_register.update(_wrapper_register)
+
+
 _instrumentation_singletons = {}
 
 
