@@ -34,11 +34,12 @@ import re
 import threading
 import time
 import timeit
+import urllib.parse
 import warnings
 from collections import defaultdict
 from datetime import timedelta
 from types import TracebackType
-from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Type, Union
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Type, TypeVar, Union
 
 import elasticapm
 from elasticapm.conf import constants
@@ -61,6 +62,7 @@ _time_func = timeit.default_timer
 execution_context = init_execution_context()
 
 SpanType = Union["Span", "DroppedSpan"]
+_AnnotatedFunctionT = TypeVar("_AnnotatedFunctionT")
 
 
 class ChildDuration(object):
@@ -231,7 +233,7 @@ class Transaction(BaseSpan):
         self._span_timers_lock = threading.Lock()
         self._dropped_span_statistics = defaultdict(lambda: {"count": 0, "duration.sum.us": 0})
         try:
-            self._breakdown = self.tracer._agent._metrics.get_metricset(
+            self._breakdown = self.tracer._agent.metrics.get_metricset(
                 "elasticapm.metrics.sets.breakdown.BreakdownMetricSet"
             )
         except (LookupError, AttributeError):
@@ -400,10 +402,12 @@ class Transaction(BaseSpan):
             result["dropped_spans_stats"] = [
                 {
                     "destination_service_resource": resource,
+                    "service_target_type": target_type,
+                    "service_target_name": target_name,
                     "outcome": outcome,
                     "duration": {"count": v["count"], "sum": {"us": int(v["duration.sum.us"])}},
                 }
-                for (resource, outcome), v in self._dropped_span_statistics.items()
+                for (resource, outcome, target_type, target_name), v in self._dropped_span_statistics.items()
             ]
         if self.sample_rate is not None:
             result["sample_rate"] = float(self.sample_rate)
@@ -468,7 +472,9 @@ class Transaction(BaseSpan):
         with self._span_timers_lock:
             try:
                 resource = span.context["destination"]["service"]["resource"]
-                stats = self._dropped_span_statistics[(resource, span.outcome)]
+                target_type = nested_key(span.context, "service", "target", "type")
+                target_name = nested_key(span.context, "service", "target", "name")
+                stats = self._dropped_span_statistics[(resource, span.outcome, target_type, target_name)]
                 stats["count"] += 1
                 stats["duration.sum.us"] += int(span.duration.total_seconds() * 1_000_000)
             except KeyError:
@@ -594,7 +600,7 @@ class Span(BaseSpan):
             # otel attributes and spankind need to be top-level
             if "otel_spankind" in self.context:
                 result["otel"] = {"span_kind": self.context.pop("otel_spankind")}
-            if elasticapm.get_client().check_server_version(gte=(7, 16)):
+            if self.tracer._agent.check_server_version(gte=(7, 16)):
                 if "otel_attributes" in self.context:
                     if "otel" not in result:
                         result["otel"] = {"attributes": self.context.pop("otel_attributes")}
@@ -625,11 +631,14 @@ class Span(BaseSpan):
         :param other_span: another span object
         :return: bool
         """
-        resource = nested_key(self.context, "destination", "service", "resource")
+        target_type = nested_key(self.context, "service", "target", "type")
+        target_name = nested_key(self.context, "service", "target", "name")
         return bool(
             self.type == other_span.type
             and self.subtype == other_span.subtype
-            and (resource and resource == nested_key(other_span.context, "destination", "service", "resource"))
+            and (target_type or target_name)
+            and target_type == nested_key(other_span.context, "service", "target", "type")
+            and target_name == nested_key(other_span.context, "service", "target", "name")
         )
 
     def is_exact_match(self, other_span: SpanType) -> bool:
@@ -663,6 +672,7 @@ class Span(BaseSpan):
         :return: None
         """
         self.autofill_resource_context()
+        self.autofill_service_target()
         super().end(skip_frames, duration)
         tracer = self.transaction.tracer
         if (
@@ -784,6 +794,32 @@ class Span(BaseSpan):
                 if "type" not in self.context["destination"]["service"]:
                     self.context["destination"]["service"]["type"] = ""
 
+    def autofill_service_target(self):
+        if self.leaf:
+            service_target = nested_key(self.context, "service", "target") or {}
+
+            if "type" not in service_target:  # infer type from span type & subtype
+                # use sub-type if provided, fallback on type othewise
+                service_target["type"] = self.subtype or self.type
+
+            if "name" not in service_target:  # infer name from span attributes
+                if nested_key(self.context, "db", "instance"):  # database spans
+                    service_target["name"] = self.context["db"]["instance"]
+                elif "message" in self.context:  # messaging spans
+                    service_target["name"] = self.context["message"]["queue"]["name"]
+                elif nested_key(self.context, "http", "url"):  # http spans
+                    url = self.context["http"]["url"]
+                    parsed_url = urllib.parse.urlparse(url)
+                    service_target["name"] = parsed_url.hostname
+                    if parsed_url.port:
+                        service_target["name"] += f":{parsed_url.port}"
+            if "service" not in self.context:
+                self.context["service"] = {}
+            self.context["service"]["target"] = service_target
+        elif nested_key(self.context, "service", "target"):
+            # non-exit spans should not have service.target.* fields
+            del self.context["service"]["target"]
+
     def cancel(self) -> None:
         """
         Mark span as cancelled. Cancelled spans don't count towards started spans nor dropped spans.
@@ -1021,7 +1057,7 @@ class capture_span(object):
         self.sync = sync
         self.links = links
 
-    def __call__(self, func: Callable) -> Callable:
+    def __call__(self, func: _AnnotatedFunctionT) -> _AnnotatedFunctionT:
         self.name = self.name or get_name_from_func(func)
 
         @functools.wraps(func)
